"""Centralized configuration for Concierge"""
import yaml
from pathlib import Path

_config_path = Path(__file__).parent.parent.parent / "configs" / "default.yaml"
_config = yaml.safe_load(_config_path.read_text())

SERVER_HOST = _config["server"]["host"]
SERVER_PORT = _config["server"]["port"]

DB_HOST = _config["database"]["host"]
DB_PORT = _config["database"]["port"]
DB_NAME = _config["database"]["name"]
DB_USER = _config["database"]["user"]
DB_PASSWORD = _config["database"]["password"]

SERVICES = _config["services"]




"""Concierge: Declarative LLM workflow framework."""

from concierge.core.state import State
from concierge.core.construct import construct, is_construct, validate_construct
from concierge.core.types import DefaultConstruct, SimpleResultConstruct
from concierge.core.task import Task, task
from concierge.core.stage import Stage, stage
from concierge.core.workflow import Workflow, workflow, StateTransfer

from concierge.engine.orchestrator import Orchestrator
from concierge.engine.language_engine import LanguageEngine
from concierge.serving.manager import SessionManager

from concierge.core.state_manager import initialize_state_manager, InMemoryStateManager
initialize_state_manager(InMemoryStateManager())

__version__ = "0.1.0"

__all__ = [
    "State",
    "construct", "is_construct", "validate_construct",
    "DefaultConstruct", "SimpleResultConstruct",
    "Task", "task",
    "Stage", "stage",
    "Workflow", "workflow", "StateTransfer",
    "Orchestrator", "LanguageEngine",
    "SessionManager"
]
